@@ -8,6 +8,7 @@ colors <- c(
   cache = "skyblue1",
   check = "skyblue1",
   analyze = "skyblue1",
+  construct = "skyblue1",
   launch = "#ff9933",
   load = "#ff9933",
   unload = "#ff7221",
@@ -85,7 +86,7 @@ color_grep <- function(text, pattern, color){
 
 # copied from the gtools package
 col2hex <- function(cname){
-  assert_pkgs("grDevices")
+  assert_pkg("grDevices")
   col_mat <- grDevices::col2rgb(cname)
   grDevices::rgb(
     red = col_mat[1, ] / 255,
