@@ -1,12 +1,23 @@
-assert_pkgs <- function(pkgs){
-  for (pkg in pkgs){
-    if (!requireNamespace(pkg, quietly = TRUE)){
-      stop(
-        "package ", pkg, " not installed. ",
-        "Install with install.packages(\"", pkg, "\").",
-        call. = FALSE
-      )
-    }
+assert_pkg <- function(pkg, version = NULL, install = "install.packages") {
+  if (!requireNamespace(pkg, quietly = TRUE)){
+    stop(
+      "package ", pkg, " not installed. ",
+      "Please install it with ", install, "(\"", pkg, "\").",
+      call. = FALSE
+    )
+  }
+  if (is.null(version)){
+    return()
+  }
+  installed_version <- as.character(utils::packageVersion(pkg))
+  is_too_old <- utils::compareVersion(installed_version, version) < 0
+  if (is_too_old){
+    stop(
+      "package ", pkg, " must be version ", version, " or greater. ",
+      "Found version ", version, " installed.",
+      "Please update it with ", install, "(\"", pkg, "\").",
+      call. = FALSE
+    )
   }
 }
 
