@@ -14,14 +14,14 @@ test_with_dir("custom Makefile recipes work", {
   e <- eval(parse(text = scenario$envir))
   jobs <- scenario$jobs
   parallelism <- scenario$parallelism
-  load_basic_example(envir = e)
+  load_mtcars_example(envir = e)
   my_plan <- e$my_plan
   verbose <- TRUE
 
   con <- make(my_plan,
     envir = e, jobs = jobs, parallelism = parallelism,
     verbose = verbose, return_config = TRUE)
-  expect_equal(sort(justbuilt(con)), sort(my_plan$target))
+  expect_equal(sort(justbuilt(con)), sort(con$plan$target))
   clean()
 
   cmds <- c(
@@ -36,7 +36,7 @@ test_with_dir("custom Makefile recipes work", {
     con <- make(my_plan, recipe_command = cmd,
       envir = e, jobs = jobs, parallelism = parallelism,
       verbose = verbose, return_config = TRUE)
-    expect_equal(sort(justbuilt(con)), sort(my_plan$target))
+    expect_equal(sort(justbuilt(con)), sort(con$plan$target))
     clean()
   }
 })
