@@ -1,6 +1,7 @@
 drake_context("lazy load")
 
 test_with_dir("no overt errors lazy load for the debug example", {
+  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   config <- dbug()
   config$verbose <- FALSE
   config$lazy_load <- TRUE
@@ -27,12 +28,13 @@ test_with_dir("no overt errors lazy load for the debug example", {
     "nextone + yourinput + 1"
   config <- testrun(config)
   expect_equal(sort(justbuilt(config)), sort(c(
-    "combined", "final", "\"intermediatefile.rds\""
+    "combined", "final", "drake_target_1"
   )))
   expect_equal(outdated(config), character(0))
 })
 
 test_with_dir("lazy loading is actually lazy", {
+  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   lazily_loaded <- c("nextone", "yourinput")
   eagerly_loaded <- "combined"
   config <- dbug()
@@ -55,6 +57,7 @@ test_with_dir("lazy loading is actually lazy", {
 })
 
 test_with_dir("active bindings", {
+  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   config <- dbug()
   if (identical(globalenv(), config$envir)){
     skip("Testing active bindings on a global environment mangles other tests.") # nolint
