@@ -7,9 +7,11 @@ test_with_dir("visNetwork graph runs", {
   pdf(NULL)
   tmp <- vis_drake_graph(config)
   dev.off()
-  pdf(NULL)
-  tmp <- vis_drake_graph(config, full_legend = FALSE)
-  dev.off()
+  for (hover in c(TRUE, FALSE)){
+    pdf(NULL)
+    tmp <- vis_drake_graph(config, full_legend = FALSE, hover = hover)
+    dev.off()
+  }
   unlink("Rplots.pdf", force = TRUE)
   file <- "graph.html"
   expect_false(file.exists(file))
@@ -17,6 +19,7 @@ test_with_dir("visNetwork graph runs", {
   expect_true(file.exists(file))
   unlink(file, force = TRUE, recursive = TRUE)
   unlink("*_files", force = TRUE, recursive = TRUE)
+  skip_on_appveyor()
   skip_if_not_installed("webshot")
   file <- "graph.png"
   expect_false(file.exists(file))
@@ -68,6 +71,7 @@ test_with_dir("Sankey diagram runs", {
   expect_false(file.exists(file))
   sankey_drake_graph(config = config, file = file, selfcontained = FALSE)
   expect_true(file.exists(file))
+  skip_on_appveyor()
   skip_if_not_installed("webshot")
   unlink(file, force = TRUE, recursive = TRUE)
   unlink("*_files", force = TRUE, recursive = TRUE)
