@@ -1,8 +1,8 @@
 drake_context("with processx")
 
 if (!identical(getOption("drake_no_processx"), TRUE)){
-  skip_on_cran() # could mess up uses of parallel
   test_with_dir("make(session = callr::r_vanilla)", {
+    skip_on_cran() # CRAN gets whitelist tests only (check time limits).
     con <- dbug()
     con$envir <- dbug_envir(globalenv())
     ls1 <- ls(envir = con$envir)
